# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/distribution/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/distribution/v1beta1/tx.proto\x12\x1b\x63osmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\x1a.cosmos/distribution/v1beta1/distribution.proto\"\xc8\x01\n\x15MsgSetWithdrawAddress\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x32\n\x10withdraw_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:F\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x11\x64\x65legator_address\x8a\xe7\xb0*#cosmos-sdk/MsgModifyWithdrawAddress\"\x1f\n\x1dMsgSetWithdrawAddressResponse\"\xda\x01\n\x1aMsgWithdrawDelegatorReward\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString:I\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x11\x64\x65legator_address\x8a\xe7\xb0*&cosmos-sdk/MsgWithdrawDelegationReward\"\x97\x01\n\"MsgWithdrawDelegatorRewardResponse\x12q\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\"\xa6\x01\n\x1eMsgWithdrawValidatorCommission\x12<\n\x11validator_address\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString:F\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x11validator_address\x8a\xe7\xb0*#cosmos-sdk/MsgWithdrawValCommission\"\x9b\x01\n&MsgWithdrawValidatorCommissionResponse\x12q\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\"\xf2\x01\n\x14MsgFundCommunityPool\x12q\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString::\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\tdepositor\x8a\xe7\xb0*\x1f\x63osmos-sdk/MsgFundCommunityPool\"\x1e\n\x1cMsgFundCommunityPoolResponse\"\xba\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12>\n\x06params\x18\x02 \x01(\x0b\x32#.cosmos.distribution.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01::\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\'cosmos-sdk/distribution/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\x85\x02\n\x15MsgCommunityPoolSpend\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x11\n\trecipient\x18\x02 \x01(\t\x12q\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01:9\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*&cosmos-sdk/distr/MsgCommunityPoolSpend\"\x1f\n\x1dMsgCommunityPoolSpendResponse\"\xc0\x02\n\x1eMsgDepositValidatorRewardsPool\x12+\n\tdepositor\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12q\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01:@\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\tdepositor\x8a\xe7\xb0*%cosmos-sdk/distr/MsgDepositValRewards\"(\n&MsgDepositValidatorRewardsPoolResponse2\xec\x07\n\x03Msg\x12\x84\x01\n\x12SetWithdrawAddress\x12\x32.cosmos.distribution.v1beta1.MsgSetWithdrawAddress\x1a:.cosmos.distribution.v1beta1.MsgSetWithdrawAddressResponse\x12\x93\x01\n\x17WithdrawDelegatorReward\x12\x37.cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward\x1a?.cosmos.distribution.v1beta1.MsgWithdrawDelegatorRewardResponse\x12\x9f\x01\n\x1bWithdrawValidatorCommission\x12;.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommission\x1a\x43.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommissionResponse\x12\x81\x01\n\x11\x46undCommunityPool\x12\x31.cosmos.distribution.v1beta1.MsgFundCommunityPool\x1a\x39.cosmos.distribution.v1beta1.MsgFundCommunityPoolResponse\x12r\n\x0cUpdateParams\x12,.cosmos.distribution.v1beta1.MsgUpdateParams\x1a\x34.cosmos.distribution.v1beta1.MsgUpdateParamsResponse\x12\x84\x01\n\x12\x43ommunityPoolSpend\x12\x32.cosmos.distribution.v1beta1.MsgCommunityPoolSpend\x1a:.cosmos.distribution.v1beta1.MsgCommunityPoolSpendResponse\x12\x9f\x01\n\x1b\x44\x65positValidatorRewardsPool\x12;.cosmos.distribution.v1beta1.MsgDepositValidatorRewardsPool\x1a\x43.cosmos.distribution.v1beta1.MsgDepositValidatorRewardsPoolResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x37Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\250\342\036\001'
  _globals['_MSGSETWITHDRAWADDRESS'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_MSGSETWITHDRAWADDRESS'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETWITHDRAWADDRESS'].fields_by_name['withdraw_address']._loaded_options = None
  _globals['_MSGSETWITHDRAWADDRESS'].fields_by_name['withdraw_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETWITHDRAWADDRESS']._loaded_options = None
  _globals['_MSGSETWITHDRAWADDRESS']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\021delegator_address\212\347\260*#cosmos-sdk/MsgModifyWithdrawAddress'
  _globals['_MSGWITHDRAWDELEGATORREWARD'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_MSGWITHDRAWDELEGATORREWARD'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGWITHDRAWDELEGATORREWARD'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGWITHDRAWDELEGATORREWARD'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGWITHDRAWDELEGATORREWARD']._loaded_options = None
  _globals['_MSGWITHDRAWDELEGATORREWARD']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\021delegator_address\212\347\260*&cosmos-sdk/MsgWithdrawDelegationReward'
  _globals['_MSGWITHDRAWDELEGATORREWARDRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGWITHDRAWDELEGATORREWARDRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION']._loaded_options = None
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\021validator_address\212\347\260*#cosmos-sdk/MsgWithdrawValCommission'
  _globals['_MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGFUNDCOMMUNITYPOOL'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGFUNDCOMMUNITYPOOL'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGFUNDCOMMUNITYPOOL'].fields_by_name['depositor']._loaded_options = None
  _globals['_MSGFUNDCOMMUNITYPOOL'].fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGFUNDCOMMUNITYPOOL']._loaded_options = None
  _globals['_MSGFUNDCOMMUNITYPOOL']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\tdepositor\212\347\260*\037cosmos-sdk/MsgFundCommunityPool'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\'cosmos-sdk/distribution/MsgUpdateParams'
  _globals['_MSGCOMMUNITYPOOLSPEND'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGCOMMUNITYPOOLSPEND'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCOMMUNITYPOOLSPEND'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGCOMMUNITYPOOLSPEND'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGCOMMUNITYPOOLSPEND']._loaded_options = None
  _globals['_MSGCOMMUNITYPOOLSPEND']._serialized_options = b'\202\347\260*\tauthority\212\347\260*&cosmos-sdk/distr/MsgCommunityPoolSpend'
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOL'].fields_by_name['depositor']._loaded_options = None
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOL'].fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOL'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOL'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOL'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOL'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOL']._loaded_options = None
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOL']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\tdepositor\212\347\260*%cosmos-sdk/distr/MsgDepositValRewards'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSETWITHDRAWADDRESS']._serialized_start=243
  _globals['_MSGSETWITHDRAWADDRESS']._serialized_end=443
  _globals['_MSGSETWITHDRAWADDRESSRESPONSE']._serialized_start=445
  _globals['_MSGSETWITHDRAWADDRESSRESPONSE']._serialized_end=476
  _globals['_MSGWITHDRAWDELEGATORREWARD']._serialized_start=479
  _globals['_MSGWITHDRAWDELEGATORREWARD']._serialized_end=697
  _globals['_MSGWITHDRAWDELEGATORREWARDRESPONSE']._serialized_start=700
  _globals['_MSGWITHDRAWDELEGATORREWARDRESPONSE']._serialized_end=851
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION']._serialized_start=854
  _globals['_MSGWITHDRAWVALIDATORCOMMISSION']._serialized_end=1020
  _globals['_MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE']._serialized_start=1023
  _globals['_MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE']._serialized_end=1178
  _globals['_MSGFUNDCOMMUNITYPOOL']._serialized_start=1181
  _globals['_MSGFUNDCOMMUNITYPOOL']._serialized_end=1423
  _globals['_MSGFUNDCOMMUNITYPOOLRESPONSE']._serialized_start=1425
  _globals['_MSGFUNDCOMMUNITYPOOLRESPONSE']._serialized_end=1455
  _globals['_MSGUPDATEPARAMS']._serialized_start=1458
  _globals['_MSGUPDATEPARAMS']._serialized_end=1644
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1646
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1671
  _globals['_MSGCOMMUNITYPOOLSPEND']._serialized_start=1674
  _globals['_MSGCOMMUNITYPOOLSPEND']._serialized_end=1935
  _globals['_MSGCOMMUNITYPOOLSPENDRESPONSE']._serialized_start=1937
  _globals['_MSGCOMMUNITYPOOLSPENDRESPONSE']._serialized_end=1968
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOL']._serialized_start=1971
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOL']._serialized_end=2291
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOLRESPONSE']._serialized_start=2293
  _globals['_MSGDEPOSITVALIDATORREWARDSPOOLRESPONSE']._serialized_end=2333
  _globals['_MSG']._serialized_start=2336
  _globals['_MSG']._serialized_end=3340
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/ratelimit/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.ratelimit import limit_params_pb2 as dydxprotocol_dot_ratelimit_dot_limit__params__pb2
from v4_proto.dydxprotocol.ratelimit import capacity_pb2 as dydxprotocol_dot_ratelimit_dot_capacity__pb2
from v4_proto.dydxprotocol.ratelimit import pending_send_packet_pb2 as dydxprotocol_dot_ratelimit_dot_pending__send__packet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dydxprotocol/ratelimit/query.proto\x12\x16\x64ydxprotocol.ratelimit\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a)dydxprotocol/ratelimit/limit_params.proto\x1a%dydxprotocol/ratelimit/capacity.proto\x1a\x30\x64ydxprotocol/ratelimit/pending_send_packet.proto\"\x18\n\x16ListLimitParamsRequest\"_\n\x17ListLimitParamsResponse\x12\x44\n\x11limit_params_list\x18\x01 \x03(\x0b\x32#.dydxprotocol.ratelimit.LimitParamsB\x04\xc8\xde\x1f\x00\",\n\x1bQueryCapacityByDenomRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"l\n\x1cQueryCapacityByDenomResponse\x12L\n\x15limiter_capacity_list\x18\x01 \x03(\x0b\x32\'.dydxprotocol.ratelimit.LimiterCapacityB\x04\xc8\xde\x1f\x00\"#\n!QueryAllPendingSendPacketsRequest\"s\n\"QueryAllPendingSendPacketsResponse\x12M\n\x14pending_send_packets\x18\x01 \x03(\x0b\x32).dydxprotocol.ratelimit.PendingSendPacketB\x04\xc8\xde\x1f\x00\x32\xb8\x04\n\x05Query\x12\xa8\x01\n\x0fListLimitParams\x12..dydxprotocol.ratelimit.ListLimitParamsRequest\x1a/.dydxprotocol.ratelimit.ListLimitParamsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/dydxprotocol/v4/ratelimit/list_limit_params\x12\xb2\x01\n\x0f\x43\x61pacityByDenom\x12\x33.dydxprotocol.ratelimit.QueryCapacityByDenomRequest\x1a\x34.dydxprotocol.ratelimit.QueryCapacityByDenomResponse\"4\x82\xd3\xe4\x93\x02.\x12,/dydxprotocol/v4/ratelimit/capacity_by_denom\x12\xce\x01\n\x15\x41llPendingSendPackets\x12\x39.dydxprotocol.ratelimit.QueryAllPendingSendPacketsRequest\x1a:.dydxprotocol.ratelimit.QueryAllPendingSendPacketsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/dydxprotocol/v4/ratelimit/get_all_pending_send_packetB=Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.ratelimit.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/types'
  _globals['_LISTLIMITPARAMSRESPONSE'].fields_by_name['limit_params_list']._loaded_options = None
  _globals['_LISTLIMITPARAMSRESPONSE'].fields_by_name['limit_params_list']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCAPACITYBYDENOMRESPONSE'].fields_by_name['limiter_capacity_list']._loaded_options = None
  _globals['_QUERYCAPACITYBYDENOMRESPONSE'].fields_by_name['limiter_capacity_list']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYALLPENDINGSENDPACKETSRESPONSE'].fields_by_name['pending_send_packets']._loaded_options = None
  _globals['_QUERYALLPENDINGSENDPACKETSRESPONSE'].fields_by_name['pending_send_packets']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['ListLimitParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListLimitParams']._serialized_options = b'\202\323\344\223\002.\022,/dydxprotocol/v4/ratelimit/list_limit_params'
  _globals['_QUERY'].methods_by_name['CapacityByDenom']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CapacityByDenom']._serialized_options = b'\202\323\344\223\002.\022,/dydxprotocol/v4/ratelimit/capacity_by_denom'
  _globals['_QUERY'].methods_by_name['AllPendingSendPackets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllPendingSendPackets']._serialized_options = b'\202\323\344\223\0028\0226/dydxprotocol/v4/ratelimit/get_all_pending_send_packet'
  _globals['_LISTLIMITPARAMSREQUEST']._serialized_start=246
  _globals['_LISTLIMITPARAMSREQUEST']._serialized_end=270
  _globals['_LISTLIMITPARAMSRESPONSE']._serialized_start=272
  _globals['_LISTLIMITPARAMSRESPONSE']._serialized_end=367
  _globals['_QUERYCAPACITYBYDENOMREQUEST']._serialized_start=369
  _globals['_QUERYCAPACITYBYDENOMREQUEST']._serialized_end=413
  _globals['_QUERYCAPACITYBYDENOMRESPONSE']._serialized_start=415
  _globals['_QUERYCAPACITYBYDENOMRESPONSE']._serialized_end=523
  _globals['_QUERYALLPENDINGSENDPACKETSREQUEST']._serialized_start=525
  _globals['_QUERYALLPENDINGSENDPACKETSREQUEST']._serialized_end=560
  _globals['_QUERYALLPENDINGSENDPACKETSRESPONSE']._serialized_start=562
  _globals['_QUERYALLPENDINGSENDPACKETSRESPONSE']._serialized_end=677
  _globals['_QUERY']._serialized_start=680
  _globals['_QUERY']._serialized_end=1248
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.feegrant.v1beta1 import feegrant_pb2 as _feegrant_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("allowances",)
    ALLOWANCES_FIELD_NUMBER: _ClassVar[int]
    allowances: _containers.RepeatedCompositeFieldContainer[_feegrant_pb2.Grant]
    def __init__(self, allowances: _Optional[_Iterable[_Union[_feegrant_pb2.Grant, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.clob import block_rate_limit_config_pb2 as dydxprotocol_dot_clob_dot_block__rate__limit__config__pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as dydxprotocol_dot_clob_dot_clob__pair__pb2
from v4_proto.dydxprotocol.clob import equity_tier_limit_config_pb2 as dydxprotocol_dot_clob_dot_equity__tier__limit__config__pb2
from v4_proto.dydxprotocol.clob import liquidations_config_pb2 as dydxprotocol_dot_clob_dot_liquidations__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/clob/genesis.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\x1a/dydxprotocol/clob/block_rate_limit_config.proto\x1a!dydxprotocol/clob/clob_pair.proto\x1a\x30\x64ydxprotocol/clob/equity_tier_limit_config.proto\x1a+dydxprotocol/clob/liquidations_config.proto\"\xbf\x02\n\x0cGenesisState\x12\x35\n\nclob_pairs\x18\x01 \x03(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00\x12H\n\x13liquidations_config\x18\x02 \x01(\x0b\x32%.dydxprotocol.clob.LiquidationsConfigB\x04\xc8\xde\x1f\x00\x12U\n\x17\x62lock_rate_limit_config\x18\x03 \x01(\x0b\x32..dydxprotocol.clob.BlockRateLimitConfigurationB\x04\xc8\xde\x1f\x00\x12W\n\x18\x65quity_tier_limit_config\x18\x04 \x01(\x0b\x32/.dydxprotocol.clob.EquityTierLimitConfigurationB\x04\xc8\xde\x1f\x00\x42\x38Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_GENESISSTATE'].fields_by_name['clob_pairs']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['clob_pairs']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['liquidations_config']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['liquidations_config']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['block_rate_limit_config']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['block_rate_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['equity_tier_limit_config']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['equity_tier_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=256
  _globals['_GENESISSTATE']._serialized_end=575
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/stats/stats.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/stats/stats.proto\x12\x12\x64ydxprotocol.stats\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"x\n\nBlockStats\x12\x32\n\x05\x66ills\x18\x01 \x03(\x0b\x32#.dydxprotocol.stats.BlockStats.Fill\x1a\x36\n\x04\x46ill\x12\r\n\x05taker\x18\x01 \x01(\t\x12\r\n\x05maker\x18\x02 \x01(\t\x12\x10\n\x08notional\x18\x03 \x01(\x04\"\'\n\rStatsMetadata\x12\x16\n\x0etrailing_epoch\x18\x01 \x01(\r\"\xd4\x01\n\nEpochStats\x12<\n\x0e\x65poch_end_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12;\n\x05stats\x18\x02 \x03(\x0b\x32,.dydxprotocol.stats.EpochStats.UserWithStats\x1aK\n\rUserWithStats\x12\x0c\n\x04user\x18\x01 \x01(\t\x12,\n\x05stats\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.stats.UserStats\"&\n\x0bGlobalStats\x12\x17\n\x0fnotional_traded\x18\x01 \x01(\x04\";\n\tUserStats\x12\x16\n\x0etaker_notional\x18\x01 \x01(\x04\x12\x16\n\x0emaker_notional\x18\x02 \x01(\x04\x42\x39Z7github.com/dydxprotocol/v4-chain/protocol/x/stats/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.stats.stats_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/stats/types'
  _globals['_EPOCHSTATS'].fields_by_name['epoch_end_time']._loaded_options = None
  _globals['_EPOCHSTATS'].fields_by_name['epoch_end_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_BLOCKSTATS']._serialized_start=109
  _globals['_BLOCKSTATS']._serialized_end=229
  _globals['_BLOCKSTATS_FILL']._serialized_start=175
  _globals['_BLOCKSTATS_FILL']._serialized_end=229
  _globals['_STATSMETADATA']._serialized_start=231
  _globals['_STATSMETADATA']._serialized_end=270
  _globals['_EPOCHSTATS']._serialized_start=273
  _globals['_EPOCHSTATS']._serialized_end=485
  _globals['_EPOCHSTATS_USERWITHSTATS']._serialized_start=410
  _globals['_EPOCHSTATS_USERWITHSTATS']._serialized_end=485
  _globals['_GLOBALSTATS']._serialized_start=487
  _globals['_GLOBALSTATS']._serialized_end=525
  _globals['_USERSTATS']._serialized_start=527
  _globals['_USERSTATS']._serialized_end=586
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.clob import order_pb2 as _order_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OrderRemoval(_message.Message):
    __slots__ = ("order_id", "removal_reason")
    class RemovalReason(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        REMOVAL_REASON_UNSPECIFIED: _ClassVar[OrderRemoval.RemovalReason]
        REMOVAL_REASON_UNDERCOLLATERALIZED: _ClassVar[OrderRemoval.RemovalReason]
        REMOVAL_REASON_INVALID_REDUCE_ONLY: _ClassVar[OrderRemoval.RemovalReason]
        REMOVAL_REASON_POST_ONLY_WOULD_CROSS_MAKER_ORDER: _ClassVar[OrderRemoval.RemovalReason]
        REMOVAL_REASON_INVALID_SELF_TRADE: _ClassVar[OrderRemoval.RemovalReason]
        REMOVAL_REASON_CONDITIONAL_FOK_COULD_NOT_BE_FULLY_FILLED: _ClassVar[OrderRemoval.RemovalReason]
        REMOVAL_REASON_CONDITIONAL_IOC_WOULD_REST_ON_BOOK: _ClassVar[OrderRemoval.RemovalReason]
        REMOVAL_REASON_FULLY_FILLED: _ClassVar[OrderRemoval.RemovalReason]
        REMOVAL_REASON_VIOLATES_ISOLATED_SUBACCOUNT_CONSTRAINTS: _ClassVar[OrderRemoval.RemovalReason]
    REMOVAL_REASON_UNSPECIFIED: OrderRemoval.RemovalReason
    REMOVAL_REASON_UNDERCOLLATERALIZED: OrderRemoval.RemovalReason
    REMOVAL_REASON_INVALID_REDUCE_ONLY: OrderRemoval.RemovalReason
    REMOVAL_REASON_POST_ONLY_WOULD_CROSS_MAKER_ORDER: OrderRemoval.RemovalReason
    REMOVAL_REASON_INVALID_SELF_TRADE: OrderRemoval.RemovalReason
    REMOVAL_REASON_CONDITIONAL_FOK_COULD_NOT_BE_FULLY_FILLED: OrderRemoval.RemovalReason
    REMOVAL_REASON_CONDITIONAL_IOC_WOULD_REST_ON_BOOK: OrderRemoval.RemovalReason
    REMOVAL_REASON_FULLY_FILLED: OrderRemoval.RemovalReason
    REMOVAL_REASON_VIOLATES_ISOLATED_SUBACCOUNT_CONSTRAINTS: OrderRemoval.RemovalReason
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    REMOVAL_REASON_FIELD_NUMBER: _ClassVar[int]
    order_id: _order_pb2.OrderId
    removal_reason: OrderRemoval.RemovalReason
    def __init__(self, order_id: _Optional[_Union[_order_pb2.OrderId, _Mapping]] = ..., removal_reason: _Optional[_Union[OrderRemoval.RemovalReason, str]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.cosmos.staking.v1beta1 import query_pb2 as cosmos_dot_staking_dot_v1beta1_dot_query__pb2

GRPC_GENERATED_VERSION = '1.64.1'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.65.0'
SCHEDULED_RELEASE_DATE = 'June 25, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmos/staking/v1beta1/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Validators = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/Validators',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsResponse.FromString,
                _registered_method=True)
        self.Validator = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/Validator',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorResponse.FromString,
                _registered_method=True)
        self.ValidatorDelegations = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/ValidatorDelegations',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsResponse.FromString,
                _registered_method=True)
        self.ValidatorUnbondingDelegations = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/ValidatorUnbondingDelegations',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsResponse.FromString,
                _registered_method=True)
        self.Delegation = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/Delegation',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationResponse.FromString,
                _registered_method=True)
        self.UnbondingDelegation = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/UnbondingDelegation',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationResponse.FromString,
                _registered_method=True)
        self.DelegatorDelegations = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/DelegatorDelegations',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsResponse.FromString,
                _registered_method=True)
        self.DelegatorUnbondingDelegations = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/DelegatorUnbondingDelegations',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsResponse.FromString,
                _registered_method=True)
        self.Redelegations = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/Redelegations',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsResponse.FromString,
                _registered_method=True)
        self.DelegatorValidators = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/DelegatorValidators',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.FromString,
                _registered_method=True)
        self.DelegatorValidator = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/DelegatorValidator',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorResponse.FromString,
                _registered_method=True)
        self.HistoricalInfo = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/HistoricalInfo',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoResponse.FromString,
                _registered_method=True)
        self.Pool = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/Pool',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolResponse.FromString,
                _registered_method=True)
        self.Params = channel.unary_unary(
                '/cosmos.staking.v1beta1.Query/Params',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Validators(self, request, context):
        """Validators queries all validators that match the given status.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Validator(self, request, context):
        """Validator queries validator info for given validator address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorDelegations(self, request, context):
        """ValidatorDelegations queries delegate info for given validator.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorUnbondingDelegations(self, request, context):
        """ValidatorUnbondingDelegations queries unbonding delegations of a validator.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delegation(self, request, context):
        """Delegation queries delegate info for given validator delegator pair.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnbondingDelegation(self, request, context):
        """UnbondingDelegation queries unbonding info for given validator delegator
        pair.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorDelegations(self, request, context):
        """DelegatorDelegations queries all delegations of a given delegator address.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorUnbondingDelegations(self, request, context):
        """DelegatorUnbondingDelegations queries all unbonding delegations of a given
        delegator address.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Redelegations(self, request, context):
        """Redelegations queries redelegations of given address.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorValidators(self, request, context):
        """DelegatorValidators queries all validators info for given delegator
        address.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorValidator(self, request, context):
        """DelegatorValidator queries validator info for given delegator validator
        pair.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HistoricalInfo(self, request, context):
        """HistoricalInfo queries the historical info for given height.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Pool(self, request, context):
        """Pool queries the pool info.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Parameters queries the staking parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Validators': grpc.unary_unary_rpc_method_handler(
                    servicer.Validators,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsResponse.SerializeToString,
            ),
            'Validator': grpc.unary_unary_rpc_method_handler(
                    servicer.Validator,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorResponse.SerializeToString,
            ),
            'ValidatorDelegations': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidatorDelegations,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsResponse.SerializeToString,
            ),
            'ValidatorUnbondingDelegations': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidatorUnbondingDelegations,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsResponse.SerializeToString,
            ),
            'Delegation': grpc.unary_unary_rpc_method_handler(
                    servicer.Delegation,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationResponse.SerializeToString,
            ),
            'UnbondingDelegation': grpc.unary_unary_rpc_method_handler(
                    servicer.UnbondingDelegation,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationResponse.SerializeToString,
            ),
            'DelegatorDelegations': grpc.unary_unary_rpc_method_handler(
                    servicer.DelegatorDelegations,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsResponse.SerializeToString,
            ),
            'DelegatorUnbondingDelegations': grpc.unary_unary_rpc_method_handler(
                    servicer.DelegatorUnbondingDelegations,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsResponse.SerializeToString,
            ),
            'Redelegations': grpc.unary_unary_rpc_method_handler(
                    servicer.Redelegations,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsResponse.SerializeToString,
            ),
            'DelegatorValidators': grpc.unary_unary_rpc_method_handler(
                    servicer.DelegatorValidators,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.SerializeToString,
            ),
            'DelegatorValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.DelegatorValidator,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorResponse.SerializeToString,
            ),
            'HistoricalInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.HistoricalInfo,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoResponse.SerializeToString,
            ),
            'Pool': grpc.unary_unary_rpc_method_handler(
                    servicer.Pool,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.staking.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.staking.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Validators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/Validators',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Validator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/Validator',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidatorDelegations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/ValidatorDelegations',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorDelegationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidatorUnbondingDelegations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/ValidatorUnbondingDelegations',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryValidatorUnbondingDelegationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delegation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/Delegation',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnbondingDelegation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/UnbondingDelegation',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryUnbondingDelegationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DelegatorDelegations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/DelegatorDelegations',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorDelegationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DelegatorUnbondingDelegations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/DelegatorUnbondingDelegations',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorUnbondingDelegationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Redelegations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/Redelegations',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryRedelegationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DelegatorValidators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/DelegatorValidators',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DelegatorValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/DelegatorValidator',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HistoricalInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/HistoricalInfo',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryHistoricalInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Pool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/Pool',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryPoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Query/Params',
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2

GRPC_GENERATED_VERSION = '1.64.1'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.65.0'
SCHEDULED_RELEASE_DATE = 'June 25, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in tendermint/abci/types_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class ABCIStub(object):
    """NOTE: When using custom types, mind the warnings.
    https://github.com/cosmos/gogoproto/blob/master/custom_types.md#warnings-and-issues

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Echo = channel.unary_unary(
                '/tendermint.abci.ABCI/Echo',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestEcho.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseEcho.FromString,
                _registered_method=True)
        self.Flush = channel.unary_unary(
                '/tendermint.abci.ABCI/Flush',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestFlush.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseFlush.FromString,
                _registered_method=True)
        self.Info = channel.unary_unary(
                '/tendermint.abci.ABCI/Info',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestInfo.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseInfo.FromString,
                _registered_method=True)
        self.CheckTx = channel.unary_unary(
                '/tendermint.abci.ABCI/CheckTx',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestCheckTx.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseCheckTx.FromString,
                _registered_method=True)
        self.Query = channel.unary_unary(
                '/tendermint.abci.ABCI/Query',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestQuery.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseQuery.FromString,
                _registered_method=True)
        self.Commit = channel.unary_unary(
                '/tendermint.abci.ABCI/Commit',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestCommit.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseCommit.FromString,
                _registered_method=True)
        self.InitChain = channel.unary_unary(
                '/tendermint.abci.ABCI/InitChain',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestInitChain.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseInitChain.FromString,
                _registered_method=True)
        self.ListSnapshots = channel.unary_unary(
                '/tendermint.abci.ABCI/ListSnapshots',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestListSnapshots.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseListSnapshots.FromString,
                _registered_method=True)
        self.OfferSnapshot = channel.unary_unary(
                '/tendermint.abci.ABCI/OfferSnapshot',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestOfferSnapshot.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseOfferSnapshot.FromString,
                _registered_method=True)
        self.LoadSnapshotChunk = channel.unary_unary(
                '/tendermint.abci.ABCI/LoadSnapshotChunk',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestLoadSnapshotChunk.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseLoadSnapshotChunk.FromString,
                _registered_method=True)
        self.ApplySnapshotChunk = channel.unary_unary(
                '/tendermint.abci.ABCI/ApplySnapshotChunk',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestApplySnapshotChunk.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseApplySnapshotChunk.FromString,
                _registered_method=True)
        self.PrepareProposal = channel.unary_unary(
                '/tendermint.abci.ABCI/PrepareProposal',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestPrepareProposal.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponsePrepareProposal.FromString,
                _registered_method=True)
        self.ProcessProposal = channel.unary_unary(
                '/tendermint.abci.ABCI/ProcessProposal',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestProcessProposal.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseProcessProposal.FromString,
                _registered_method=True)
        self.ExtendVote = channel.unary_unary(
                '/tendermint.abci.ABCI/ExtendVote',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestExtendVote.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseExtendVote.FromString,
                _registered_method=True)
        self.VerifyVoteExtension = channel.unary_unary(
                '/tendermint.abci.ABCI/VerifyVoteExtension',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestVerifyVoteExtension.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseVerifyVoteExtension.FromString,
                _registered_method=True)
        self.FinalizeBlock = channel.unary_unary(
                '/tendermint.abci.ABCI/FinalizeBlock',
                request_serializer=tendermint_dot_abci_dot_types__pb2.RequestFinalizeBlock.SerializeToString,
                response_deserializer=tendermint_dot_abci_dot_types__pb2.ResponseFinalizeBlock.FromString,
                _registered_method=True)


class ABCIServicer(object):
    """NOTE: When using custom types, mind the warnings.
    https://github.com/cosmos/gogoproto/blob/master/custom_types.md#warnings-and-issues

    """

    def Echo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Flush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Info(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckTx(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Query(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Commit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitChain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSnapshots(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OfferSnapshot(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadSnapshotChunk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplySnapshotChunk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PrepareProposal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProcessProposal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExtendVote(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyVoteExtension(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FinalizeBlock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ABCIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Echo': grpc.unary_unary_rpc_method_handler(
                    servicer.Echo,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestEcho.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseEcho.SerializeToString,
            ),
            'Flush': grpc.unary_unary_rpc_method_handler(
                    servicer.Flush,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestFlush.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseFlush.SerializeToString,
            ),
            'Info': grpc.unary_unary_rpc_method_handler(
                    servicer.Info,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestInfo.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseInfo.SerializeToString,
            ),
            'CheckTx': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckTx,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestCheckTx.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseCheckTx.SerializeToString,
            ),
            'Query': grpc.unary_unary_rpc_method_handler(
                    servicer.Query,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestQuery.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseQuery.SerializeToString,
            ),
            'Commit': grpc.unary_unary_rpc_method_handler(
                    servicer.Commit,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestCommit.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseCommit.SerializeToString,
            ),
            'InitChain': grpc.unary_unary_rpc_method_handler(
                    servicer.InitChain,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestInitChain.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseInitChain.SerializeToString,
            ),
            'ListSnapshots': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSnapshots,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestListSnapshots.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseListSnapshots.SerializeToString,
            ),
            'OfferSnapshot': grpc.unary_unary_rpc_method_handler(
                    servicer.OfferSnapshot,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestOfferSnapshot.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseOfferSnapshot.SerializeToString,
            ),
            'LoadSnapshotChunk': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadSnapshotChunk,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestLoadSnapshotChunk.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseLoadSnapshotChunk.SerializeToString,
            ),
            'ApplySnapshotChunk': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplySnapshotChunk,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestApplySnapshotChunk.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseApplySnapshotChunk.SerializeToString,
            ),
            'PrepareProposal': grpc.unary_unary_rpc_method_handler(
                    servicer.PrepareProposal,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestPrepareProposal.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponsePrepareProposal.SerializeToString,
            ),
            'ProcessProposal': grpc.unary_unary_rpc_method_handler(
                    servicer.ProcessProposal,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestProcessProposal.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseProcessProposal.SerializeToString,
            ),
            'ExtendVote': grpc.unary_unary_rpc_method_handler(
                    servicer.ExtendVote,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestExtendVote.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseExtendVote.SerializeToString,
            ),
            'VerifyVoteExtension': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyVoteExtension,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestVerifyVoteExtension.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseVerifyVoteExtension.SerializeToString,
            ),
            'FinalizeBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.FinalizeBlock,
                    request_deserializer=tendermint_dot_abci_dot_types__pb2.RequestFinalizeBlock.FromString,
                    response_serializer=tendermint_dot_abci_dot_types__pb2.ResponseFinalizeBlock.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tendermint.abci.ABCI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('tendermint.abci.ABCI', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ABCI(object):
    """NOTE: When using custom types, mind the warnings.
    https://github.com/cosmos/gogoproto/blob/master/custom_types.md#warnings-and-issues

    """

    @staticmethod
    def Echo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/Echo',
            tendermint_dot_abci_dot_types__pb2.RequestEcho.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseEcho.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Flush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/Flush',
            tendermint_dot_abci_dot_types__pb2.RequestFlush.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseFlush.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Info(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/Info',
            tendermint_dot_abci_dot_types__pb2.RequestInfo.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CheckTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/CheckTx',
            tendermint_dot_abci_dot_types__pb2.RequestCheckTx.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseCheckTx.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Query(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/Query',
            tendermint_dot_abci_dot_types__pb2.RequestQuery.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseQuery.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Commit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/Commit',
            tendermint_dot_abci_dot_types__pb2.RequestCommit.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseCommit.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InitChain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/InitChain',
            tendermint_dot_abci_dot_types__pb2.RequestInitChain.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseInitChain.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSnapshots(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/ListSnapshots',
            tendermint_dot_abci_dot_types__pb2.RequestListSnapshots.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseListSnapshots.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OfferSnapshot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/OfferSnapshot',
            tendermint_dot_abci_dot_types__pb2.RequestOfferSnapshot.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseOfferSnapshot.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LoadSnapshotChunk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/LoadSnapshotChunk',
            tendermint_dot_abci_dot_types__pb2.RequestLoadSnapshotChunk.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseLoadSnapshotChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ApplySnapshotChunk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/ApplySnapshotChunk',
            tendermint_dot_abci_dot_types__pb2.RequestApplySnapshotChunk.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseApplySnapshotChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PrepareProposal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/PrepareProposal',
            tendermint_dot_abci_dot_types__pb2.RequestPrepareProposal.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponsePrepareProposal.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProcessProposal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/ProcessProposal',
            tendermint_dot_abci_dot_types__pb2.RequestProcessProposal.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseProcessProposal.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExtendVote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/ExtendVote',
            tendermint_dot_abci_dot_types__pb2.RequestExtendVote.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseExtendVote.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VerifyVoteExtension(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/VerifyVoteExtension',
            tendermint_dot_abci_dot_types__pb2.RequestVerifyVoteExtension.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseVerifyVoteExtension.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FinalizeBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tendermint.abci.ABCI/FinalizeBlock',
            tendermint_dot_abci_dot_types__pb2.RequestFinalizeBlock.SerializeToString,
            tendermint_dot_abci_dot_types__pb2.ResponseFinalizeBlock.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgVerifyInvariant(_message.Message):
    __slots__ = ("sender", "invariant_module_name", "invariant_route")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    INVARIANT_MODULE_NAME_FIELD_NUMBER: _ClassVar[int]
    INVARIANT_ROUTE_FIELD_NUMBER: _ClassVar[int]
    sender: str
    invariant_module_name: str
    invariant_route: str
    def __init__(self, sender: _Optional[str] = ..., invariant_module_name: _Optional[str] = ..., invariant_route: _Optional[str] = ...) -> None: ...

class MsgVerifyInvariantResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateParams(_message.Message):
    __slots__ = ("authority", "constant_fee")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    CONSTANT_FEE_FIELD_NUMBER: _ClassVar[int]
    authority: str
    constant_fee: _coin_pb2.Coin
    def __init__(self, authority: _Optional[str] = ..., constant_fee: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class MsgUpdateParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vault/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/vault/params.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\"\x99\x02\n\x06Params\x12\x0e\n\x06layers\x18\x01 \x01(\r\x12\x16\n\x0espread_min_ppm\x18\x02 \x01(\r\x12\x19\n\x11spread_buffer_ppm\x18\x03 \x01(\r\x12\x17\n\x0fskew_factor_ppm\x18\x04 \x01(\r\x12\x1a\n\x12order_size_pct_ppm\x18\x05 \x01(\r\x12 \n\x18order_expiration_seconds\x18\x06 \x01(\r\x12u\n#activation_threshold_quote_quantums\x18\x07 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableIntB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_PARAMS'].fields_by_name['activation_threshold_quote_quantums']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['activation_threshold_quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_PARAMS']._serialized_start=78
  _globals['_PARAMS']._serialized_end=359
# @@protoc_insertion_point(module_scope)



from v4_proto.amino import amino_pb2 as _amino_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Equivocation(_message.Message):
    __slots__ = ("height", "time", "power", "consensus_address")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    POWER_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    height: int
    time: _timestamp_pb2.Timestamp
    power: int
    consensus_address: str
    def __init__(self, height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., power: _Optional[int] = ..., consensus_address: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/bridge/bridge_event.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&dydxprotocol/bridge/bridge_event.proto\x12\x13\x64ydxprotocol.bridge\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x8d\x01\n\x0b\x42ridgeEvent\x12\n\n\x02id\x18\x01 \x01(\r\x12-\n\x04\x63oin\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12)\n\x07\x61\x64\x64ress\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x18\n\x10\x65th_block_height\x18\x04 \x01(\x04\x42:Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.bridge.bridge_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/types'
  _globals['_BRIDGEEVENT'].fields_by_name['coin']._loaded_options = None
  _globals['_BRIDGEEVENT'].fields_by_name['coin']._serialized_options = b'\310\336\037\000'
  _globals['_BRIDGEEVENT'].fields_by_name['address']._loaded_options = None
  _globals['_BRIDGEEVENT'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_BRIDGEEVENT']._serialized_start=145
  _globals['_BRIDGEEVENT']._serialized_end=286
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crypto/ed25519/keys.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/crypto/ed25519/keys.proto\x12\x15\x63osmos.crypto.ed25519\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"d\n\x06PubKey\x12)\n\x03key\x18\x01 \x01(\x0c\x42\x1c\xfa\xde\x1f\x18\x63rypto/ed25519.PublicKey:/\x98\xa0\x1f\x00\x8a\xe7\xb0*\x18tendermint/PubKeyEd25519\x92\xe7\xb0*\tkey_field\"c\n\x07PrivKey\x12*\n\x03key\x18\x01 \x01(\x0c\x42\x1d\xfa\xde\x1f\x19\x63rypto/ed25519.PrivateKey:,\x8a\xe7\xb0*\x19tendermint/PrivKeyEd25519\x92\xe7\xb0*\tkey_fieldB2Z0github.com/cosmos/cosmos-sdk/crypto/keys/ed25519b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.ed25519.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/cosmos/cosmos-sdk/crypto/keys/ed25519'
  _globals['_PUBKEY'].fields_by_name['key']._loaded_options = None
  _globals['_PUBKEY'].fields_by_name['key']._serialized_options = b'\372\336\037\030crypto/ed25519.PublicKey'
  _globals['_PUBKEY']._loaded_options = None
  _globals['_PUBKEY']._serialized_options = b'\230\240\037\000\212\347\260*\030tendermint/PubKeyEd25519\222\347\260*\tkey_field'
  _globals['_PRIVKEY'].fields_by_name['key']._loaded_options = None
  _globals['_PRIVKEY'].fields_by_name['key']._serialized_options = b'\372\336\037\031crypto/ed25519.PrivateKey'
  _globals['_PRIVKEY']._loaded_options = None
  _globals['_PRIVKEY']._serialized_options = b'\212\347\260*\031tendermint/PrivKeyEd25519\222\347\260*\tkey_field'
  _globals['_PUBKEY']._serialized_start=100
  _globals['_PUBKEY']._serialized_end=200
  _globals['_PRIVKEY']._serialized_start=202
  _globals['_PRIVKEY']._serialized_end=301
# @@protoc_insertion_point(module_scope)



from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.cosmos.authz.v1beta1 import authz_pb2 as _authz_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryGrantsRequest(_message.Message):
    __slots__ = ("granter", "grantee", "msg_type_url", "pagination")
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    granter: str
    grantee: str
    msg_type_url: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, granter: _Optional[str] = ..., grantee: _Optional[str] = ..., msg_type_url: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryGrantsResponse(_message.Message):
    __slots__ = ("grants", "pagination")
    GRANTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grants: _containers.RepeatedCompositeFieldContainer[_authz_pb2.Grant]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, grants: _Optional[_Iterable[_Union[_authz_pb2.Grant, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGranterGrantsRequest(_message.Message):
    __slots__ = ("granter", "pagination")
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    granter: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, granter: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryGranterGrantsResponse(_message.Message):
    __slots__ = ("grants", "pagination")
    GRANTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grants: _containers.RepeatedCompositeFieldContainer[_authz_pb2.GrantAuthorization]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, grants: _Optional[_Iterable[_Union[_authz_pb2.GrantAuthorization, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGranteeGrantsRequest(_message.Message):
    __slots__ = ("grantee", "pagination")
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, grantee: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryGranteeGrantsResponse(_message.Message):
    __slots__ = ("grants", "pagination")
    GRANTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grants: _containers.RepeatedCompositeFieldContainer[_authz_pb2.GrantAuthorization]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, grants: _Optional[_Iterable[_Union[_authz_pb2.GrantAuthorization, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/feegrant/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos.feegrant.v1beta1 import feegrant_pb2 as cosmos_dot_feegrant_dot_v1beta1_dot_feegrant__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/feegrant/v1beta1/genesis.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/feegrant/v1beta1/feegrant.proto\x1a\x11\x61mino/amino.proto\"M\n\x0cGenesisState\x12=\n\nallowances\x18\x01 \x03(\x0b\x32\x1e.cosmos.feegrant.v1beta1.GrantB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x42\x19Z\x17\x63osmossdk.io/x/feegrantb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027cosmossdk.io/x/feegrant'
  _globals['_GENESISSTATE'].fields_by_name['allowances']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['allowances']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE']._serialized_start=147
  _globals['_GENESISSTATE']._serialized_end=224
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MarketPrice(_message.Message):
    __slots__ = ("id", "exponent", "price")
    ID_FIELD_NUMBER: _ClassVar[int]
    EXPONENT_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    id: int
    exponent: int
    price: int
    def __init__(self, id: _Optional[int] = ..., exponent: _Optional[int] = ..., price: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/subaccounts/subaccount.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.dydxprotocol.subaccounts import asset_position_pb2 as dydxprotocol_dot_subaccounts_dot_asset__position__pb2
from v4_proto.dydxprotocol.subaccounts import perpetual_position_pb2 as dydxprotocol_dot_subaccounts_dot_perpetual__position__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)dydxprotocol/subaccounts/subaccount.proto\x12\x18\x64ydxprotocol.subaccounts\x1a\x19\x63osmos_proto/cosmos.proto\x1a-dydxprotocol/subaccounts/asset_position.proto\x1a\x31\x64ydxprotocol/subaccounts/perpetual_position.proto\"G\n\x0cSubaccountId\x12\'\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x0e\n\x06number\x18\x02 \x01(\r\"\xe4\x01\n\nSubaccount\x12\x32\n\x02id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12@\n\x0f\x61sset_positions\x18\x02 \x03(\x0b\x32\'.dydxprotocol.subaccounts.AssetPosition\x12H\n\x13perpetual_positions\x18\x03 \x03(\x0b\x32+.dydxprotocol.subaccounts.PerpetualPosition\x12\x16\n\x0emargin_enabled\x18\x04 \x01(\x08\x42?Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.subaccounts.subaccount_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/types'
  _globals['_SUBACCOUNTID'].fields_by_name['owner']._loaded_options = None
  _globals['_SUBACCOUNTID'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_SUBACCOUNTID']._serialized_start=196
  _globals['_SUBACCOUNTID']._serialized_end=267
  _globals['_SUBACCOUNT']._serialized_start=270
  _globals['_SUBACCOUNT']._serialized_end=498
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/tx/v1beta1/service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.abci.v1beta1 import abci_pb2 as cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2
from v4_proto.cosmos.tx.v1beta1 import tx_pb2 as cosmos_dot_tx_dot_v1beta1_dot_tx__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
from v4_proto.tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/tx/v1beta1/service.proto\x12\x11\x63osmos.tx.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a#cosmos/base/abci/v1beta1/abci.proto\x1a\x1a\x63osmos/tx/v1beta1/tx.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1ctendermint/types/block.proto\x1a\x1ctendermint/types/types.proto\"\xc2\x01\n\x12GetTxsEventRequest\x12\x12\n\x06\x65vents\x18\x01 \x03(\tB\x02\x18\x01\x12>\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestB\x02\x18\x01\x12,\n\x08order_by\x18\x03 \x01(\x0e\x32\x1a.cosmos.tx.v1beta1.OrderBy\x12\x0c\n\x04page\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x04\x12\r\n\x05query\x18\x06 \x01(\t\"\xc5\x01\n\x13GetTxsEventResponse\x12\"\n\x03txs\x18\x01 \x03(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12:\n\x0ctx_responses\x18\x02 \x03(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\x12?\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseB\x02\x18\x01\x12\r\n\x05total\x18\x04 \x01(\x04\"V\n\x12\x42roadcastTxRequest\x12\x10\n\x08tx_bytes\x18\x01 \x01(\x0c\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .cosmos.tx.v1beta1.BroadcastMode\"P\n\x13\x42roadcastTxResponse\x12\x39\n\x0btx_response\x18\x01 \x01(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\"J\n\x0fSimulateRequest\x12%\n\x02tx\x18\x01 \x01(\x0b\x32\x15.cosmos.tx.v1beta1.TxB\x02\x18\x01\x12\x10\n\x08tx_bytes\x18\x02 \x01(\x0c\"y\n\x10SimulateResponse\x12\x33\n\x08gas_info\x18\x01 \x01(\x0b\x32!.cosmos.base.abci.v1beta1.GasInfo\x12\x30\n\x06result\x18\x02 \x01(\x0b\x32 .cosmos.base.abci.v1beta1.Result\"\x1c\n\x0cGetTxRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\"m\n\rGetTxResponse\x12!\n\x02tx\x18\x01 \x01(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12\x39\n\x0btx_response\x18\x02 \x01(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\"d\n\x16GetBlockWithTxsRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xcf\x01\n\x17GetBlockWithTxsResponse\x12\"\n\x03txs\x18\x01 \x03(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12+\n\x08\x62lock_id\x18\x02 \x01(\x0b\x32\x19.tendermint.types.BlockID\x12&\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x17.tendermint.types.Block\x12;\n\npagination\x18\x04 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"#\n\x0fTxDecodeRequest\x12\x10\n\x08tx_bytes\x18\x01 \x01(\x0c\"5\n\x10TxDecodeResponse\x12!\n\x02tx\x18\x01 \x01(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\"4\n\x0fTxEncodeRequest\x12!\n\x02tx\x18\x01 \x01(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\"$\n\x10TxEncodeResponse\x12\x10\n\x08tx_bytes\x18\x01 \x01(\x0c\"*\n\x14TxEncodeAminoRequest\x12\x12\n\namino_json\x18\x01 \x01(\t\"-\n\x15TxEncodeAminoResponse\x12\x14\n\x0c\x61mino_binary\x18\x01 \x01(\x0c\",\n\x14TxDecodeAminoRequest\x12\x14\n\x0c\x61mino_binary\x18\x01 \x01(\x0c\"+\n\x15TxDecodeAminoResponse\x12\x12\n\namino_json\x18\x01 \x01(\t*H\n\x07OrderBy\x12\x18\n\x14ORDER_BY_UNSPECIFIED\x10\x00\x12\x10\n\x0cORDER_BY_ASC\x10\x01\x12\x11\n\rORDER_BY_DESC\x10\x02*\x80\x01\n\rBroadcastMode\x12\x1e\n\x1a\x42ROADCAST_MODE_UNSPECIFIED\x10\x00\x12\x1c\n\x14\x42ROADCAST_MODE_BLOCK\x10\x01\x1a\x02\x08\x01\x12\x17\n\x13\x42ROADCAST_MODE_SYNC\x10\x02\x12\x18\n\x14\x42ROADCAST_MODE_ASYNC\x10\x03\x32\xaa\t\n\x07Service\x12{\n\x08Simulate\x12\".cosmos.tx.v1beta1.SimulateRequest\x1a#.cosmos.tx.v1beta1.SimulateResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/cosmos/tx/v1beta1/simulate:\x01*\x12q\n\x05GetTx\x12\x1f.cosmos.tx.v1beta1.GetTxRequest\x1a .cosmos.tx.v1beta1.GetTxResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/tx/v1beta1/txs/{hash}\x12\x7f\n\x0b\x42roadcastTx\x12%.cosmos.tx.v1beta1.BroadcastTxRequest\x1a&.cosmos.tx.v1beta1.BroadcastTxResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/cosmos/tx/v1beta1/txs:\x01*\x12|\n\x0bGetTxsEvent\x12%.cosmos.tx.v1beta1.GetTxsEventRequest\x1a&.cosmos.tx.v1beta1.GetTxsEventResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/cosmos/tx/v1beta1/txs\x12\x97\x01\n\x0fGetBlockWithTxs\x12).cosmos.tx.v1beta1.GetBlockWithTxsRequest\x1a*.cosmos.tx.v1beta1.GetBlockWithTxsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/cosmos/tx/v1beta1/txs/block/{height}\x12y\n\x08TxDecode\x12\".cosmos.tx.v1beta1.TxDecodeRequest\x1a#.cosmos.tx.v1beta1.TxDecodeResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/cosmos/tx/v1beta1/decode:\x01*\x12y\n\x08TxEncode\x12\".cosmos.tx.v1beta1.TxEncodeRequest\x1a#.cosmos.tx.v1beta1.TxEncodeResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/cosmos/tx/v1beta1/encode:\x01*\x12\x8e\x01\n\rTxEncodeAmino\x12\'.cosmos.tx.v1beta1.TxEncodeAminoRequest\x1a(.cosmos.tx.v1beta1.TxEncodeAminoResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/cosmos/tx/v1beta1/encode/amino:\x01*\x12\x8e\x01\n\rTxDecodeAmino\x12\'.cosmos.tx.v1beta1.TxDecodeAminoRequest\x1a(.cosmos.tx.v1beta1.TxDecodeAminoResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/cosmos/tx/v1beta1/decode/amino:\x01*B\'Z%github.com/cosmos/cosmos-sdk/types/txb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.tx.v1beta1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z%github.com/cosmos/cosmos-sdk/types/tx'
  _globals['_BROADCASTMODE'].values_by_name["BROADCAST_MODE_BLOCK"]._loaded_options = None
  _globals['_BROADCASTMODE'].values_by_name["BROADCAST_MODE_BLOCK"]._serialized_options = b'\010\001'
  _globals['_GETTXSEVENTREQUEST'].fields_by_name['events']._loaded_options = None
  _globals['_GETTXSEVENTREQUEST'].fields_by_name['events']._serialized_options = b'\030\001'
  _globals['_GETTXSEVENTREQUEST'].fields_by_name['pagination']._loaded_options = None
  _globals['_GETTXSEVENTREQUEST'].fields_by_name['pagination']._serialized_options = b'\030\001'
  _globals['_GETTXSEVENTRESPONSE'].fields_by_name['pagination']._loaded_options = None
  _globals['_GETTXSEVENTRESPONSE'].fields_by_name['pagination']._serialized_options = b'\030\001'
  _globals['_SIMULATEREQUEST'].fields_by_name['tx']._loaded_options = None
  _globals['_SIMULATEREQUEST'].fields_by_name['tx']._serialized_options = b'\030\001'
  _globals['_SERVICE'].methods_by_name['Simulate']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['Simulate']._serialized_options = b'\202\323\344\223\002 \"\033/cosmos/tx/v1beta1/simulate:\001*'
  _globals['_SERVICE'].methods_by_name['GetTx']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['GetTx']._serialized_options = b'\202\323\344\223\002\037\022\035/cosmos/tx/v1beta1/txs/{hash}'
  _globals['_SERVICE'].methods_by_name['BroadcastTx']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['BroadcastTx']._serialized_options = b'\202\323\344\223\002\033\"\026/cosmos/tx/v1beta1/txs:\001*'
  _globals['_SERVICE'].methods_by_name['GetTxsEvent']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['GetTxsEvent']._serialized_options = b'\202\323\344\223\002\030\022\026/cosmos/tx/v1beta1/txs'
  _globals['_SERVICE'].methods_by_name['GetBlockWithTxs']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['GetBlockWithTxs']._serialized_options = b'\202\323\344\223\002\'\022%/cosmos/tx/v1beta1/txs/block/{height}'
  _globals['_SERVICE'].methods_by_name['TxDecode']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['TxDecode']._serialized_options = b'\202\323\344\223\002\036\"\031/cosmos/tx/v1beta1/decode:\001*'
  _globals['_SERVICE'].methods_by_name['TxEncode']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['TxEncode']._serialized_options = b'\202\323\344\223\002\036\"\031/cosmos/tx/v1beta1/encode:\001*'
  _globals['_SERVICE'].methods_by_name['TxEncodeAmino']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['TxEncodeAmino']._serialized_options = b'\202\323\344\223\002$\"\037/cosmos/tx/v1beta1/encode/amino:\001*'
  _globals['_SERVICE'].methods_by_name['TxDecodeAmino']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['TxDecodeAmino']._serialized_options = b'\202\323\344\223\002$\"\037/cosmos/tx/v1beta1/decode/amino:\001*'
  _globals['_ORDERBY']._serialized_start=1838
  _globals['_ORDERBY']._serialized_end=1910
  _globals['_BROADCASTMODE']._serialized_start=1913
  _globals['_BROADCASTMODE']._serialized_end=2041
  _globals['_GETTXSEVENTREQUEST']._serialized_start=254
  _globals['_GETTXSEVENTREQUEST']._serialized_end=448
  _globals['_GETTXSEVENTRESPONSE']._serialized_start=451
  _globals['_GETTXSEVENTRESPONSE']._serialized_end=648
  _globals['_BROADCASTTXREQUEST']._serialized_start=650
  _globals['_BROADCASTTXREQUEST']._serialized_end=736
  _globals['_BROADCASTTXRESPONSE']._serialized_start=738
  _globals['_BROADCASTTXRESPONSE']._serialized_end=818
  _globals['_SIMULATEREQUEST']._serialized_start=820
  _globals['_SIMULATEREQUEST']._serialized_end=894
  _globals['_SIMULATERESPONSE']._serialized_start=896
  _globals['_SIMULATERESPONSE']._serialized_end=1017
  _globals['_GETTXREQUEST']._serialized_start=1019
  _globals['_GETTXREQUEST']._serialized_end=1047
  _globals['_GETTXRESPONSE']._serialized_start=1049
  _globals['_GETTXRESPONSE']._serialized_end=1158
  _globals['_GETBLOCKWITHTXSREQUEST']._serialized_start=1160
  _globals['_GETBLOCKWITHTXSREQUEST']._serialized_end=1260
  _globals['_GETBLOCKWITHTXSRESPONSE']._serialized_start=1263
  _globals['_GETBLOCKWITHTXSRESPONSE']._serialized_end=1470
  _globals['_TXDECODEREQUEST']._serialized_start=1472
  _globals['_TXDECODEREQUEST']._serialized_end=1507
  _globals['_TXDECODERESPONSE']._serialized_start=1509
  _globals['_TXDECODERESPONSE']._serialized_end=1562
  _globals['_TXENCODEREQUEST']._serialized_start=1564
  _globals['_TXENCODEREQUEST']._serialized_end=1616
  _globals['_TXENCODERESPONSE']._serialized_start=1618
  _globals['_TXENCODERESPONSE']._serialized_end=1654
  _globals['_TXENCODEAMINOREQUEST']._serialized_start=1656
  _globals['_TXENCODEAMINOREQUEST']._serialized_end=1698
  _globals['_TXENCODEAMINORESPONSE']._serialized_start=1700
  _globals['_TXENCODEAMINORESPONSE']._serialized_end=1745
  _globals['_TXDECODEAMINOREQUEST']._serialized_start=1747
  _globals['_TXDECODEAMINOREQUEST']._serialized_end=1791
  _globals['_TXDECODEAMINORESPONSE']._serialized_start=1793
  _globals['_TXDECODEAMINORESPONSE']._serialized_end=1836
  _globals['_SERVICE']._serialized_start=2044
  _globals['_SERVICE']._serialized_end=3238
# @@protoc_insertion_point(module_scope)
